window.Gleam.initSearch([{"doc":"radiate","title":"radiate","content":"# radiate\n\n[![Package Version](https://img.shields.io/hexpm/v/radiate)](https://hex.pm/packages/radiate)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/radiate/)\n\nHot reloading while in development for Gleam!\n\n## Introduction\n\nRadiate will watch any directory you specify for changes. When a file is\nchanged in that directory, it&#39;ll check if it&#39;s a Gleam file, and if it is, the\nproject will be recompiled and all modified modules will be reloaded, without\nhaving to restart the BEAM VM.\n\n## Quick start\n\n```gleam\n// On main.gleam\nimport gleam/erlang/process\nimport gleam/io\nimport radiate\nimport message\n\npub fn main() {\n  let _ =\n    radiate.new()\n    |&gt; radiate.add_dir(&quot;src&quot;)\n    |&gt; radiate.start()\n\n  let timer_subject = process.new_subject()\n\n  print_every_second(timer_subject)\n}\n\nfn print_every_second(subject: process.Subject(Nil)) {\n  process.send_after(subject, 1000, Nil)\n\n  let _ = process.receive(subject, 1500)\n  io.println(message.get_message())\n\n  print_every_second(subject)\n}\n\n// On message.gleam\npub fn get_message() -&gt; String {\n  &quot;Hello!&quot;\n}\n```\n\nWhen you first run this, it&#39;ll print &quot;Hello!&quot; every second.\n\nNow, go ahead and change the text `get_message` returns to `&quot;Hello, world!&quot;`, and save the file.\n\nAs soon as you save, the message printed is changed to &quot;Hello, world!&quot;, without needing to restart the program!\n\n## Adding a callback\n\nYou can add callbacks to be run every time code is reloaded through `on_reload`:\n\n```gleam\nimport radiate\nimport gleam/io\n\npub fn main() {\n  let _ = radiate.new()\n    |&gt; radiate.add_dir(&quot;src&quot;)\n    |&gt; radiate.on_reload(fn (path) {\n      io.println(&quot;Change in &quot; &lt;&gt; path &lt;&gt; &quot;, reloading!&quot;)\n    })\n    |&gt; radiate.start()\n}\n```\n\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add radiate\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/reloader&gt;.\n","url":"index.html"},{"doc":"radiate","title":"Builder","content":"pub opaque type Builder(has_dirs)\n Opaque builder type for reloader. Create with `new`.\n\nSynonyms:\nradiate.Builder\nradiate Builder","url":"radiate.html#Builder"},{"doc":"radiate","title":"HasDirectories","content":"pub type HasDirectories\n Phantom type to indicate directories have been added\n\nSynonyms:\nradiate.HasDirectories\nradiate HasDirectories","url":"radiate.html#HasDirectories"},{"doc":"radiate","title":"NoDirectories","content":"pub type NoDirectories\n Phantom type to indicate no directories are added\n\nSynonyms:\nradiate.NoDirectories\nradiate NoDirectories","url":"radiate.html#NoDirectories"},{"doc":"radiate","title":"add_dir","content":"pub fn add_dir(builder: Builder(a), dir: String) -&gt; Builder(\n  HasDirectories,\n)\n\nSynonyms:\nradiate.add_dir\nradiate add_dir","url":"radiate.html#add_dir"},{"doc":"radiate","title":"new","content":"pub fn new() -&gt; Builder(NoDirectories)\n Construct a new builder\nSynonyms:\nradiate.new\nradiate new","url":"radiate.html#new"},{"doc":"radiate","title":"on_reload","content":"pub fn on_reload(builder: Builder(a), callback: fn(String) -&gt; Nil) -&gt; Builder(\n  a,\n)\n Add a callback to be run after reload\nSynonyms:\nradiate.on_reload\nradiate on_reload","url":"radiate.html#on_reload"},{"doc":"radiate","title":"start","content":"pub fn start(builder: Builder(HasDirectories)) -&gt; Result(\n  Subject(Change),\n  StartError,\n)\n Start reloader\nSynonyms:\nradiate.start\nradiate start","url":"radiate.html#start"},{"doc":"radiate","title":"radiate","content":"","url":"radiate.html"}]);